=======
Credits
=======

Development Lead
----------------

* Jesse Cusack <jmcusack@ucsd.edu>
* Gunnar Voet <gvoet@ucsd.edu>

Contributors
------------

* Henri Drake <https://github.com/hdrake>

Other
-----

Most of the functions collected here were adapted from prior versions written
by a number of oceanographers. Where authorship was documented in the code,
credit to authors of prior versions is given in the docstrings.
